@@ -13,6 +13,57 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
+func TestV1RegistriesConfNonempty(t *testing.T) {
+	for _, c := range []V1RegistriesConf{
+		{},
+		{V1TOMLConfig: V1TOMLConfig{Search: V1TOMLregistries{Registries: []string{}}}},
+		{V1TOMLConfig: V1TOMLConfig{Insecure: V1TOMLregistries{Registries: []string{}}}},
+		{V1TOMLConfig: V1TOMLConfig{Block: V1TOMLregistries{Registries: []string{}}}},
+	} {
+		copy := c // A shallow copy
+		res := copy.Nonempty()
+		assert.False(t, res, c)
+		assert.Equal(t, c, copy, c) // Ensure the method did not change the original value
+	}
+	for _, c := range []V1RegistriesConf{
+		{V1TOMLConfig: V1TOMLConfig{Search: V1TOMLregistries{Registries: []string{"example.com"}}}},
+		{V1TOMLConfig: V1TOMLConfig{Insecure: V1TOMLregistries{Registries: []string{"example.com"}}}},
+		{V1TOMLConfig: V1TOMLConfig{Block: V1TOMLregistries{Registries: []string{"example.com"}}}},
+	} {
+		copy := c // A shallow copy
+		res := copy.Nonempty()
+		assert.True(t, res, c)
+		assert.Equal(t, c, copy, c) // Ensure the method did not change the original value
+	}
+}
+
+func TestV2RegistriesConfNonempty(t *testing.T) {
+	for _, c := range []V2RegistriesConf{
+		{},
+		{Registries: []Registry{}},
+		{UnqualifiedSearchRegistries: []string{}},
+		{CredentialHelpers: []string{}},
+		{shortNameAliasConf: shortNameAliasConf{Aliases: map[string]string{}}},
+	} {
+		copy := c // A shallow copy
+		res := copy.Nonempty()
+		assert.False(t, res, c)
+		assert.Equal(t, c, copy, c) // Ensure the method did not change the original value
+	}
+	for _, c := range []V2RegistriesConf{
+		{Registries: []Registry{{Prefix: "example.com"}}},
+		{UnqualifiedSearchRegistries: []string{"example.com"}},
+		{CredentialHelpers: []string{"a"}},
+		{ShortNameMode: "enforcing"},
+		{shortNameAliasConf: shortNameAliasConf{Aliases: map[string]string{"a": "example.com/b"}}},
+	} {
+		copy := c // A shallow copy
+		res := copy.Nonempty()
+		assert.True(t, res, c)
+		assert.Equal(t, c, copy, c) // Ensure the method did not change the original value
+	}
+}
+
 func TestParseLocation(t *testing.T) {
 	var err error
 	var location string
@@ -427,7 +478,7 @@ func TestMixingV1andV2(t *testing.T) {
 		SystemRegistriesConfPath:    "testdata/mixing-v1-v2.conf",
 		SystemRegistriesConfDirPath: "testdata/this-does-not-exist",
 	})
-	assert.NotNil(t, err)
+	require.Error(t, err)
 	assert.Contains(t, err.Error(), "mixing sysregistry v1/v2 is not supported")
 }
 
